@@ -165,15 +165,16 @@ url: http://testing.fr/cubicweb/task/%s\n''' % done.eid)
 
         MAILBOX[:] = ()
         # fake revision from the main repo of our patch repo
+        atrevision = [self.session.entity_from_eid(patch3_2.revisions[-1].eid)]
         revision = mock_object(repository=self.vcsrepo,
                                description='applied patch patch3.diff',
                                author='syt',
                                eid=patch3_2.revisions[-1].rev.eid,
-                               reverse_from_revision=[
-                                   self.session.entity_from_eid(patch3_2.revisions[-1].eid)])
+                               reverse_at_revision=atrevision,
+                               reverse_from_revision=atrevision)
         # hi-hack vcsrepo._cw to avoid connections pool pb
         self.vcsrepo._cw = self.session
-        self.session.set_pool()
+        self.session.set_cnxset()
         op = hooks.SearchPatchStateInstructionOp.get_instance(self.session)
         op.add_data(revision)
         self.commit() # will process our fake operation
